==> ikapi-0.3.5.tgz: package/src/API/IKUtils.js <==
import AWS from "aws-sdk";
import { Marshaller } from '@aws/dynamodb-auto-marshaller';
//
export default class IKUtils {}
IKUtils.isOffline = function() { return process.env.IS_OFFLINE; }
IKUtils.logLevel = function() { return process.env.LOG_LEVEL; }
//formatting
IKUtils.toDoubleDigit = function(str) { return String("0" + str).slice(-2); }
IKUtils.isValidString = function(string) { return (string && string.length > 0 && !Array.isArray(string)); }
IKUtils.isValidNumber = function(number) {
  let validNumb = NaN;
  try { validNumb = parseInt(number + ""); }
  catch (e) { }
  return !isNaN(validNumb) && !Array.isArray(number);
}
//
IKUtils.caseInsensitiveObjectForKey = function(obj, key) {
  if (!obj) return null;
  const insensitiveKey = Object.keys(obj).find(k => k.toLowerCase() === key.toLowerCase());
  if (insensitiveKey && insensitiveKey != '') return obj[insensitiveKey];
  return null;
}
IKUtils.caseInsensitiveSetObjectForKey = function(obj, key, value) {
  if (!obj) return null;
  const insensitiveKey = Object.keys(obj).find(k => k.toLowerCase() === key.toLowerCase());
  if (insensitiveKey && insensitiveKey != '') obj[insensitiveKey] = value;
}
//DB
IKUtils.encapsulateForDB = function(item) {
  if (Array.isArray(item)) return {L: item.map(_i => IKUtils.encapsulateForDB(_i))};
  else if (typeof item === 'object') {
    console.log('->', item);
    const marshaller = new Marshaller({onEmpty: 'omit'});
    return {M: marshaller.marshallItem(item)};
  } else return AWS.DynamoDB.Converter.input(item);
}
IKUtils.decapsulateForDB = function(item) {
  if (!item && item !== false) return null;
  if (Array.isArray(item)) {
    return item.map(_item => IKUtils.decapsulateForDB(_item));
  } else if (typeof item === 'object') {
    const marshaller = new Marshaller({onEmpty: 'omit'});
    return marshaller.unmarshallItem(item);
  } return item;
}

==> ikapi-0.3.8.tgz: package/src/API/IKUtils.js <==
import AWS from "aws-sdk";
import { Marshaller } from '@aws/dynamodb-auto-marshaller';
//
export default class IKUtils {}
IKUtils.isOffline = function() { return process.env.IS_OFFLINE; }
IKUtils.logLevel = function() { return process.env.LOG_LEVEL; }
//formatting
IKUtils.toDoubleDigit = function(str) { return String("0" + str).slice(-2); }
IKUtils.isValidString = function(string) { return (string && string.length > 0 && !Array.isArray(string)); }
IKUtils.isValidNumber = function(number) {
  let validNumb = NaN;
  try { validNumb = parseInt(number + ""); }
  catch (e) { }
  return !isNaN(validNumb) && !Array.isArray(number);
}
//
IKUtils.caseInsensitiveObjectForKey = function(obj, key) {
  if (!obj) return null;
  const insensitiveKey = Object.keys(obj).find(k => k.toLowerCase() === key.toLowerCase());
  if (insensitiveKey && insensitiveKey != '') return obj[insensitiveKey];
  return null;
}
IKUtils.caseInsensitiveSetObjectForKey = function(obj, key, value) {
  if (!obj) return null;
  const insensitiveKey = Object.keys(obj).find(k => k.toLowerCase() === key.toLowerCase());
  if (insensitiveKey && insensitiveKey != '') obj[insensitiveKey] = value;
}
//DB
IKUtils.encapsulateForDB = function(item) {
  if (Array.isArray(item)) return {L: item.map(_i => IKUtils.encapsulateForDB(_i))};
  else if (typeof item === 'object') {
    console.log('->', item, typeof item);
    const marshaller = new Marshaller({onEmpty: 'omit'});
    console.log('done')
    return {M: marshaller.marshallItem(item)};
  } else return AWS.DynamoDB.Converter.input(item);
}
IKUtils.decapsulateForDB = function(item) {
  if (!item && item !== false) return null;
  if (Array.isArray(item)) {
    return item.map(_item => IKUtils.decapsulateForDB(_item));
  } else if (typeof item === 'object') {
    const marshaller = new Marshaller({onEmpty: 'omit'});
    return marshaller.unmarshallItem(item);
  } return item;
}
